@@ -13,8 +13,6 @@ urlpatterns = [
     path("edc_reference/", include("edc_reference.urls")),
     path("edc_visit_schedule/", include("edc_visit_schedule.urls")),
     path("meta_consent/", include("meta_consent.urls")),
-    path(
-        "administration", RedirectView.as_view(url="admin/"), name="administration_url"
-    ),
+    path("administration", RedirectView.as_view(url="admin/"), name="administration_url"),
     path("", RedirectView.as_view(url="admin/"), name="home_url"),
 ]
