@@ -1,8 +1,10 @@
-from .end_of_study_admin import EndOfStudyPhaseThreeAdmin
+from .end_of_study_admin import EndOfStudyAdmin
 from .loss_to_followup_admin import LossToFollowupAdmin
 from .offschedule_admin import OffScheduleAdmin
 from .offschedule_postnatal_admin import OffSchedulePostnatalAdmin
 from .offschedule_pregnancy_admin import OffSchedulePregnancyAdmin
+from .offstudy_medication_admin import OffstudyMedicationAdmin
 from .onschedule_admin import OnScheduleAdmin
 from .pregnancy_notification_admin import PregnancyNotificationAdmin
-from .protocol_deviation_violation_admin import ProtocolDeviationViolationAdmin
+from .protocol_incident_admin import ProtocolDeviationViolationAdmin
+from .subject_transfer_admin import SubjectTransferAdmin
