@@ -1,11 +1,11 @@
 from edc_constants.constants import NO, NOT_APPLICABLE, YES
 
 BMI_FBG_OGTT_INCOMPLETE = "BMI/FBG/OGTT incomplete"
-BMI_IFT_OGTT = "BMI/FBG/OGTT"
+BMI_FBG_OGTT = "BMI/FBG/OGTT"
 EGFR_NOT_CALCULATED = "eGFR not calculated"
 EGFR_LT_45 = "eGFR<45"
 FBG_OGTT_INCOMPLETE = "FBG/OGTT incomplete"
-IFT_OGTT = "FBG/OGTT"
+FBG_OGTT = "FBG/OGTT"
 PART_ONE = "p1"
 PART_TWO = "p2"
 PART_THREE = "p3"
@@ -18,3 +18,8 @@ PREG_YES_NO_NA = (
 
 CONVERSION_FACTOR = 18.018018
 SEVERE_HTN = "Severe HTN"
+PENDING_REPEAT = "pending_p3_repeat"
+PRE_DM = "pre_dm"
+HI_OGTT = "hi_ogtt"
+NORMAL_FBG_OGTT = "normal_fbg_ogtt"
+HI_FBG = "hi_fbg"
